@@ -1,8 +1,9 @@
-from .common import Entity
+from .common import (
+    Entity, Domain, DataDict, RecordList)
 from .repository import (
     Repository, MemoryRepository,
     JsonRepository, SqlRepository, RestRepository)
 
 __author__ = 'Knowark'
 __email__ = 'info@knowark.com'
-__version__ = '0.3.2'
+__version__ = '0.3.3'
